#[repr(u8)]pub enum BlockFlag {
Opaque = 1,
Grass = 2,
Foliage = 4,
Birch = 8,
Spruce = 16,
Water = 32,
WallSign = 64,
}Expand description
Flags describing special properties of BlockTypes
Variants
Opaque = 1
The block type is opaque
Grass = 2
The block type is colored using biome grass colors
Foliage = 4
The block type is colored using biome foliage colors
Birch = 8
The block type is birch foliage
Spruce = 16
The block type is spruce foliage
Water = 32
The block type is colored using biome water colors
WallSign = 64
The block type is a wall sign
The WallSign flag is used to distinguish wall signs from freestanding or -hanging signs.