#[repr(u8)]
pub enum BlockFlag { Opaque = 1, Grass = 2, Foliage = 4, Birch = 8, Spruce = 16, Water = 32, }
Flags describing special properties of BlockTypes

Variants



Opaque = 1

The block type is opaque



Grass = 2

The block type is colored using biome grass colors



Foliage = 4

The block type is colored using biome foliage colors



Birch = 8

The block type is birch foliage



Spruce = 16

The block type is spurce foliage



Water = 32

The block type is colored using biome water colors